<TS version="2.1" language="az@latin">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation type="unfinished">Ünvana və ya etiketə düzəliş etmək üçün sağ klikləyin</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation type="unfinished">Yeni bir ünvan yaradın</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">&amp;Yeni</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished">&amp;Kopyala</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished">Bağla</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation type="unfinished">Hazırki seçilmiş ünvanı siyahıdan sil</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation type="unfinished">Axtarmaq üçün ünvan və ya etiket daxil edin</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Hazırki vərəqdəki verilənləri fayla ixrac edin</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;İxrac</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished">&amp;Sil</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation type="unfinished">Pul göndəriləcək ünvanı seçin</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation type="unfinished">Pul alınacaq ünvanı seçin</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation type="unfinished">Seç</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation type="unfinished">Bunlar ödənişləri göndərmək üçün Bitcoin ünvanlarınızdır. pul göndərməzdən əvvəl həmişə miqdarı və göndəriləcək ünvanı yoxlayın.</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for receiving payments. Use the 'Create new receiving address' button in the receive tab to create new addresses.
Signing is only possible with addresses of the type 'legacy'.</source>
        <translation type="unfinished">Bunlar ödəniş almaq üçün Bitcoin ünvanlarınızdır. Yeni ünvan yaratmaq üçün alacaqlar vərəqində 'Yeni alacaq ünvan yarat' düyməsini istifadə edin.
Daxil olma, yalnız 'qanuni' tipli ünvanlar ilə mümkündür.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation type="unfinished">&amp;Ünvanı kopyala</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation type="unfinished">Etiketi kopyala</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished">&amp;Düzəliş et</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation type="unfinished">Ünvan siyahısını ixrac et</translation>
    </message>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">Vergüllə ayrılmış fayl</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <extracomment>An error message. %1 is a stand-in argument for the name of the file we attempted to save to.</extracomment>
        <translation type="unfinished">Ünvan siyahısını %1 daxilində saxlamağı sınayarkən xəta baş verdi. Zəhmət olmasa yenidən sınayın.</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">İxrac edilmədi</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">Etiket</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">Ünvan</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(etiket yoxdur)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation type="unfinished">Şifrə İfadə Dialoqu</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation type="unfinished">Şifrə ifadəsini daxil edin</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation type="unfinished">Yeni şifrə ifadəsi</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation type="unfinished">Şifrə ifadəsini təkrarlayın</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation type="unfinished">Şifrə ifadəsini göstər</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation type="unfinished">Şifrəli pulqabı</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation type="unfinished">Bu əməliyyatın pulqabı kilidini açılması üçün pul qabınızın şifrə ifadəsinə ehtiyacı var.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation type="unfinished">Pulqabı kilidini aç</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation type="unfinished">Şifrə ifadəsini dəyişdir</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation type="unfinished">Pulqabı şifrələməsini təsdiqlə</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation type="unfinished">Xəbərdarlıq: Əgər siz pulqabınızı şifrədən çıxarsanız və şifrəli sözü itirmiş olsanız &lt;b&gt;BÜTÜN BİTCOİNLƏRİNİZİ İTİRƏCƏKSİNİZ&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation type="unfinished">Pulqabınızı şifrədən çıxarmaq istədiyinizə əminsiniz?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation type="unfinished">Pulqabı şifrələndi.</translation>
    </message>
    <message>
        <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation type="unfinished">Pulqabı üçün yeni şifrəli sözü daxil edin.&lt;br/&gt;Lütfən &lt;b&gt;on və daha çox qarışıq simvollardan&lt;/b&gt; və ya &lt;b&gt;səkkiz və daha çox sayda sözdən&lt;/b&gt; ibarət şifrəli söz istifadə edin.</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase for the wallet.</source>
        <translation type="unfinished">Pulqabı üçün köhnə şifrəli sözü və yeni şifrəli sözü daxil edin</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation type="unfinished">Davam et</translation>
    </message>
    <message>
        <source>Remember that encrypting your wallet cannot fully protect your bitcoins from being stolen by malware infecting your computer.</source>
        <translation type="unfinished">Unutmayın ki, pulqabınızın şifrələməsi bitcoinlərinizi kompüterinizə zərərli proqram tərəfindən oğurlanmaqdan tamamilə qoruya bilməz.</translation>
    </message>
    <message>
        <source>Wallet to be encrypted</source>
        <translation type="unfinished">Pulqabı şifrələnəcək</translation>
    </message>
    <message>
        <source>Your wallet is about to be encrypted. </source>
        <translation type="unfinished">Pulqabınız şifrələnmək üzrədir.</translation>
    </message>
    <message>
        <source>Your wallet is now encrypted. </source>
        <translation type="unfinished">Pulqabınız artıq şifrələnib.</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation type="unfinished">VACİBDİR: Pulqabınızın əvvəlki ehtiyyat nüsxələri yenicə yaradılan şifrələnmiş cüzdan ilə əvəz olunmalıdır. Təhlükəsizlik baxımından yeni şifrələnmiş pulqabını işə salan kimi əvvəlki şifrəsi açılmış pulqabının ehtiyyat nüsxələri qeyri-işlək olacaqdır.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation type="unfinished">Cüzdanın şifrələnməsi baş tutmadı</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation type="unfinished">Daxili xəta səbəbindən cüzdanın şifrələnməsi baş tutmadı. Cüzdanınız şifrələnmədi.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation type="unfinished">Təqdim etdiyiniz şifrəli söz uyğun deyil.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation type="unfinished">Cüzdanın şifrədən çıxarılması baş tutmadı</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation type="unfinished">Cüzdanı şifrədən çıxarmaq üçün daxil etdiyiniz şifrəli söz səhvdir.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation type="unfinished">Cüzdanın şifrəli sözü uğurla dəyişdirildi.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation type="unfinished">Xəbərdarlıq: Caps Lock düyməsi yanılıdır!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>Banned Until</source>
        <translation type="unfinished">Qadağan edildi</translation>
    </message>
</context>
<context>
    <name>BitcoinApplication</name>
    <message>
        <source>Settings file %1 might be corrupt or invalid.</source>
        <translation type="unfinished">Ola bilsin ki, %1 faylı zədələnib və ya yararsızdır.</translation>
    </message>
    <message>
        <source>Runaway exception</source>
        <translation type="unfinished">İdarə edilə bilməyən istisna</translation>
    </message>
    <message>
        <source>A fatal error occurred. %1 can no longer continue safely and will quit.</source>
        <translation type="unfinished">Ciddi xəta baş verdi. %1 təhlükəsiz davam etdirilə bilməz və bağlanacaqdır.</translation>
    </message>
    <message>
        <source>Internal error</source>
        <translation type="unfinished">Daxili xəta</translation>
    </message>
    <message>
        <source>An internal error occurred. %1 will attempt to continue safely. This is an unexpected bug which can be reported as described below.</source>
        <translation type="unfinished">Daxili xəta baş verdi. %1 təhlükəsiz davam etməyə cəhd edəcək. Bu gözlənilməz bir xətadır və onun haqqında aşağıdakı şəkildə bildirmək olar.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Do you want to reset settings to default values, or to abort without making changes?</source>
        <extracomment>Explanatory text shown on startup when the settings file cannot be read. Prompts user to make a choice between resetting or aborting.</extracomment>
        <translation type="unfinished">Siz ayarları dəyərləri ilkin dəyərlərinə sıfırlamaq istəyirsiniz, yoxsa dəyişiklik etmədən bu əməliyyatı ləğv etmək istəyirsiniz?</translation>
    </message>
    <message>
        <source>A fatal error occurred. Check that settings file is writable, or try running with -nosettings.</source>
        <extracomment>Explanatory text shown on startup when the settings file could not be written. Prompts user to check that we have the ability to write to the file. Explains that the user has the option of running without a settings file.</extracomment>
        <translation type="unfinished">Ciddi xəta baş verdi. Ayarlar faylının yazılabilən olduğunu yoxlayın və ya -nonsettings (ayarlarsız) parametri ilə işə salın.</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">XƏta: %1</translation>
    </message>
    <message>
        <source>%1 didn't yet exit safely…</source>
        <translation type="unfinished">%1 hələ də təhlükəsiz bağlanmayıb...</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation type="unfinished">naməlum</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Məbləğ</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform>%n second(s)</numerusform>
            <numerusform>%n second(s)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform>%n minute(s)</numerusform>
            <numerusform>%n minute(s)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform>%n hour(s)</numerusform>
            <numerusform>%n hour(s)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform>%n day(s)</numerusform>
            <numerusform>%n day(s)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform>%n week(s)</numerusform>
            <numerusform>%n week(s)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform>%n year(s)</numerusform>
            <numerusform>%n year(s)</numerusform>
        </translation>
    </message>
    <message>
        <source>default wallet</source>
        <translation type="unfinished">standart cüzdan</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Overview</source>
        <translation type="unfinished">&amp;İcmal</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation type="unfinished">Cüzdanın əsas icmalı göstərilsin</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation type="unfinished">&amp;Köçürmələr</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation type="unfinished">Köçürmə tarixçəsinə baxış</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation type="unfinished">Çı&amp;xış</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation type="unfinished">Tətbiqdən çıxış</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation type="unfinished">%1 h&amp;aqqında</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation type="unfinished">%1 haqqında məlumatlar göstərilsin</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation type="unfinished">&amp;Qt haqqında</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation type="unfinished">Qt haqqında məlumatlar göstərilsin</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation type="unfinished">%1 üçün tənzimləmə seçimlərini dəyişin</translation>
    </message>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">Yeni cüzdan yaradın</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation type="unfinished">&amp;Yığın</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Cüzdan:</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">İnternet bağlantısı söndürülüb.</translation>
    </message>
    <message>
        <source>Proxy is &lt;b&gt;enabled&lt;/b&gt;: %1</source>
        <translation type="unfinished">Proksi &lt;b&gt;işə salınıb&lt;/b&gt;: %1</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation type="unfinished">Pulları Bitcoin ünvanına göndərin</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation type="unfinished">Cüzdanın ehtiyyat nüsxəsini başqa yerdə saxlayın</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation type="unfinished">Cüzdanın şifrələnməsi üçün istifadə olunan şifrəli sözü dəyişin</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation type="unfinished">&amp;Göndərin</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation type="unfinished">&amp;Qəbul edin</translation>
    </message>
    <message>
        <source>&amp;Options…</source>
        <translation type="unfinished">&amp;Parametrlər</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet…</source>
        <translation type="unfinished">&amp;Cüzdanı şifrələyin...</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation type="unfinished">Cüzdanınıza aid məxfi açarları şifrələyin</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet…</source>
        <translation type="unfinished">&amp;Cüzdanın ehtiyyat nüsxəsini saxlayın...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase…</source>
        <translation type="unfinished">&amp;Şifrəli sözü dəyişin...</translation>
    </message>
    <message>
        <source>Sign &amp;message…</source>
        <translation type="unfinished">İs&amp;marıcı imzalayın...</translation>
    </message>
    <message>
        <source>Sign messages with your Bitcoin addresses to prove you own them</source>
        <translation type="unfinished">Bitcoin ünvanlarınızın sahibi olduğunuzu sübut etmək üçün ismarıcları imzalayın</translation>
    </message>
    <message>
        <source>&amp;Verify message…</source>
        <translation type="unfinished">&amp;İsmarıcı doğrulayın...</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Bitcoin addresses</source>
        <translation type="unfinished">Göstərilmiş Bitcoin ünvanları ilə imzalandıqlarına əmin olmaq üçün ismarıcları doğrulayın</translation>
    </message>
    <message>
        <source>&amp;Load PSBT from file…</source>
        <translation type="unfinished">PSBT-i fayldan yük&amp;ləyin...</translation>
    </message>
    <message>
        <source>Open &amp;URI…</source>
        <translation type="unfinished">&amp;URI-ni açın...</translation>
    </message>
    <message>
        <source>Close Wallet…</source>
        <translation type="unfinished">Cüzdanı bağlayın...</translation>
    </message>
    <message>
        <source>Create Wallet…</source>
        <translation type="unfinished">Cüzdan yaradın...</translation>
    </message>
    <message>
        <source>Close All Wallets…</source>
        <translation type="unfinished">Bütün cüzdanları bağlayın...</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished">&amp;Fayl</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation type="unfinished">&amp;Tənzimləmələr</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished">&amp;Kömək</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation type="unfinished">Vərəq alətlər zolağı</translation>
    </message>
    <message>
        <source>Syncing Headers (%1%)…</source>
        <translation type="unfinished">Başlıqlar eyniləşdirilir (%1%)...</translation>
    </message>
    <message>
        <source>Synchronizing with network…</source>
        <translation type="unfinished">İnternet şəbəkəsi ilə eyniləşdirmə...</translation>
    </message>
    <message>
        <source>Indexing blocks on disk…</source>
        <translation type="unfinished">Bloklar diskdə indekslənir...</translation>
    </message>
    <message>
        <source>Processing blocks on disk…</source>
        <translation type="unfinished">Bloklar diskdə icra olunur...</translation>
    </message>
    <message>
        <source>Connecting to peers…</source>
        <translation type="unfinished">İştirakçılara qoşulur...</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and bitcoin: URIs)</source>
        <translation type="unfinished">Ödəmə tələbi (QR-kodlar və Bitcoin URI-ləri yaradılır):</translation>
    </message>
    <message>
        <source>Show the list of used sending addresses and labels</source>
        <translation type="unfinished">İstifadə olunmuş göndərmə ünvanlarının və etiketlərin siyahısını göstərmək </translation>
    </message>
    <message>
        <source>Show the list of used receiving addresses and labels</source>
        <translation type="unfinished">İstifadə edilmiş qəbuletmə ünvanlarının və etiketlərin siyahısını göstərmək</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation type="unfinished">Əmr &amp;sətri parametrləri</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform>Köçürmə tarixçəsinin %n bloku işləndi.</numerusform>
            <numerusform>Köçürmə tarixçəsinin %n bloku işləndi.</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation type="unfinished">%1 geridə qalır</translation>
    </message>
    <message>
        <source>Catching up…</source>
        <translation type="unfinished">Eyniləşir...</translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation type="unfinished">Sonuncu qəbul edilmiş blok %1 əvvəl yaradılıb.</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation type="unfinished">Bundan sonrakı köçürmələr hələlik görünməyəcək.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Xəta</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished">Xəbərdarlıq</translation>
    </message>
    <message>
        <source>Information</source>
        <translation type="unfinished">Məlumat</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation type="unfinished">Eyniləşdirildi</translation>
    </message>
    <message>
        <source>Load Partially Signed Bitcoin Transaction</source>
        <translation type="unfinished">Qismən imzalanmış Bitcoin köçürmələrini yükləyin</translation>
    </message>
    <message>
        <source>Load PSBT from &amp;clipboard…</source>
        <translation type="unfinished">PSBT-i &amp;mübadilə yaddaşından yükləyin...</translation>
    </message>
    <message>
        <source>Load Partially Signed Bitcoin Transaction from clipboard</source>
        <translation type="unfinished">Qismən İmzalanmış Bitcoin Köçürməsini (PSBT) mübadilə yaddaşından yükləmək</translation>
    </message>
    <message>
        <source>Node window</source>
        <translation type="unfinished">Qovşaq pəncərəsi</translation>
    </message>
    <message>
        <source>Open node debugging and diagnostic console</source>
        <translation type="unfinished">Qovşaq sazlaması və diaqnostika konsolunu açın</translation>
    </message>
    <message>
        <source>&amp;Sending addresses</source>
        <translation type="unfinished">&amp;Göndərmək üçün ünvanlar</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses</source>
        <translation type="unfinished">&amp;Qəbul etmək üçün ünvanlar</translation>
    </message>
    <message>
        <source>Open a bitcoin: URI</source>
        <translation type="unfinished">Bitcoin açın: URI</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <translation type="unfinished">Cüzdanı açın</translation>
    </message>
    <message>
        <source>Open a wallet</source>
        <translation type="unfinished">Bir pulqabı aç</translation>
    </message>
    <message>
        <source>Close wallet</source>
        <translation type="unfinished">Cüzdanı bağlayın</translation>
    </message>
    <message>
        <source>Restore Wallet…</source>
        <extracomment>Name of the menu item that restores wallet from a backup file.</extracomment>
        <translation type="unfinished">Cüzdanı bərpa edin...</translation>
    </message>
    <message>
        <source>Restore a wallet from a backup file</source>
        <extracomment>Status tip for Restore Wallet menu item</extracomment>
        <translation type="unfinished">Cüzdanı ehtiyyat nüsxə faylından bərpa edin</translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation type="unfinished">Bütün cüzdanları bağlayın</translation>
    </message>
    <message>
        <source>Show the %1 help message to get a list with possible Bitcoin command-line options</source>
        <translation type="unfinished">Mümkün Bitcoin əmr sətri əməliyyatları siyahısını almaq üçün %1 kömək ismarıcı göstərilsin</translation>
    </message>
    <message>
        <source>&amp;Mask values</source>
        <translation type="unfinished">&amp;Dəyərləri gizlədin</translation>
    </message>
    <message>
        <source>Mask the values in the Overview tab</source>
        <translation type="unfinished">İcmal vərəqində dəyərləri gizlədin</translation>
    </message>
    <message>
        <source>No wallets available</source>
        <translation type="unfinished">Heç bir cüzdan yoxdur</translation>
    </message>
    <message>
        <source>Wallet Data</source>
        <extracomment>Name of the wallet data file format.</extracomment>
        <translation type="unfinished">Cüzdanı verilənləri</translation>
    </message>
    <message>
        <source>Load Wallet Backup</source>
        <extracomment>The title for Restore Wallet File Windows</extracomment>
        <translation type="unfinished">Cüzdan ehtiyyat nesxəsini yüklə</translation>
    </message>
    <message>
        <source>Restore Wallet</source>
        <extracomment>Title of pop-up window shown when the user is attempting to restore a wallet.</extracomment>
        <translation type="unfinished">Cüzdanı bərpa et</translation>
    </message>
    <message>
        <source>Wallet Name</source>
        <extracomment>Label of the input field where the name of the wallet is entered.</extracomment>
        <translation type="unfinished">Pulqabının adı</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished">&amp;Pəncərə</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation type="unfinished">Miqyas</translation>
    </message>
    <message>
        <source>Main Window</source>
        <translation type="unfinished">Əsas pəncərə</translation>
    </message>
    <message>
        <source>%1 client</source>
        <translation type="unfinished">%1 müştəri</translation>
    </message>
    <message>
        <source>&amp;Hide</source>
        <translation type="unfinished">&amp;Gizlədin</translation>
    </message>
    <message>
        <source>S&amp;how</source>
        <translation type="unfinished">&amp;Göstərin</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform>Bitcoin şəbəkəsinə %n aktiv bağlantı.</numerusform>
            <numerusform>Bitcoin şəbəkəsinə %n aktiv bağlantı.</numerusform>
        </translation>
    </message>
    <message>
        <source>Click for more actions.</source>
        <extracomment>A substring of the tooltip. "More actions" are available via the context menu.</extracomment>
        <translation type="unfinished">Daha çıx əməllər üçün vurun.</translation>
    </message>
    <message>
        <source>Show Peers tab</source>
        <extracomment>A context menu item. The "Peers tab" is an element of the "Node window".</extracomment>
        <translation type="unfinished">İştirakşılar vərəqini göstərmək</translation>
    </message>
    <message>
        <source>Disable network activity</source>
        <extracomment>A context menu item.</extracomment>
        <translation type="unfinished">Şəbəkə bağlantısını söndürün</translation>
    </message>
    <message>
        <source>Enable network activity</source>
        <extracomment>A context menu item. The network activity was disabled previously.</extracomment>
        <translation type="unfinished">Şəbəkə bağlantısını açın</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">XƏta: %1</translation>
    </message>
    <message>
        <source>Warning: %1</source>
        <translation type="unfinished">Xəbərdarlıq: %1</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation type="unfinished">Tarix: %1
</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation type="unfinished">Məbləğ: %1
</translation>
    </message>
    <message>
        <source>Wallet: %1
</source>
        <translation type="unfinished">Cüzdan: %1
</translation>
    </message>
    <message>
        <source>Type: %1
</source>
        <translation type="unfinished">Növ: %1
</translation>
    </message>
    <message>
        <source>Label: %1
</source>
        <translation type="unfinished">Etiket: %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation type="unfinished">Ünvan: %1
</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation type="unfinished">Göndərilmiş köçürmə</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation type="unfinished">Daxil olan köçürmə</translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;enabled&lt;/b&gt;</source>
        <translation type="unfinished">HD açar yaradılması &lt;b&gt;aktivdir&lt;/b&gt;</translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;disabled&lt;/b&gt;</source>
        <translation type="unfinished">HD açar yaradılması &lt;b&gt;söndürülüb&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Private key &lt;b&gt;disabled&lt;/b&gt;</source>
        <translation type="unfinished">Məxfi açar &lt;b&gt;söndürülüb&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation type="unfinished">Cüzdan &lt;b&gt;şifrələnib&lt;/b&gt; və hal-hazırda &lt;b&gt;kiliddən çıxarılıb&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation type="unfinished">Cüzdan &lt;b&gt;şifrələnib&lt;/b&gt; və hal-hazırda &lt;b&gt;kiliddlənib&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Original message:</source>
        <translation type="unfinished">Orijinal ismarıc:</translation>
    </message>
</context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    <message>
        <source>Unit to show amounts in. Click to select another unit.</source>
        <translation type="unfinished">Məbləğin vahidi. Başqa vahidi seçmək üçün vurun.</translation>
    </message>
</context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Coin Selection</source>
        <translation type="unfinished">Pul seçimi</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation type="unfinished">Miqdar:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation type="unfinished">Baytlar:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Məbləğ:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation type="unfinished">Komissiya:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation type="unfinished">Komissiydan sonra:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation type="unfinished">Qalıq:</translation>
    </message>
    <message>
        <source>(un)select all</source>
        <translation type="unfinished">seçim</translation>
    </message>
    <message>
        <source>Tree mode</source>
        <translation type="unfinished">Ağac rejimi</translation>
    </message>
    <message>
        <source>List mode</source>
        <translation type="unfinished">Siyahı rejim</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Məbləğ</translation>
    </message>
    <message>
        <source>Received with label</source>
        <translation type="unfinished">Etiket ilə alındı</translation>
    </message>
    <message>
        <source>Received with address</source>
        <translation type="unfinished">Ünvan ilə alındı</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">Tarix</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation type="unfinished">Təsdiqləmələr</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation type="unfinished">Təsdiqləndi</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation type="unfinished">Məbləği kopyalayın</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Ünvanı kopyalayın</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">&amp;Etiketi kopyalayın</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">&amp;Məbləği kopyalayın</translation>
    </message>
    <message>
        <source>Copy transaction &amp;ID and output index</source>
        <translation type="unfinished">Köçürmə &amp;İD-sini və çıxış indeksini kopyalayın</translation>
    </message>
    <message>
        <source>L&amp;ock unspent</source>
        <translation type="unfinished">Xərclənməmiş qalığı &amp;kilidləyin</translation>
    </message>
    <message>
        <source>&amp;Unlock unspent</source>
        <translation type="unfinished">Xərclənməmiş qalığı kilidd'n &amp;çıxarın</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation type="unfinished">Miqdarı kopyalayın</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation type="unfinished">Komissiyanı kopyalayın</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation type="unfinished">Komissyadan sonra kopyalayın</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation type="unfinished">Baytları koyalayın</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation type="unfinished">Dəyişikliyi kopyalayın</translation>
    </message>
    <message>
        <source>(%1 locked)</source>
        <translation type="unfinished">(%1 kilidləndi)</translation>
    </message>
    <message>
        <source>Can vary +/- %1 satoshi(s) per input.</source>
        <translation type="unfinished">Hər daxilolmada +/- %1 satoşi dəyişə bilər.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(etiket yoxdur)</translation>
    </message>
    <message>
        <source>change from %1 (%2)</source>
        <translation type="unfinished">bunlardan qalıq: %1 (%2)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation type="unfinished">(qalıq)</translation>
    </message>
</context>
<context>
    <name>CreateWalletActivity</name>
    <message>
        <source>Create Wallet</source>
        <extracomment>Title of window indicating the progress of creation of a new wallet.</extracomment>
        <translation type="unfinished">Cüzdan yaradın</translation>
    </message>
    <message>
        <source>Creating Wallet &lt;b&gt;%1&lt;/b&gt;…</source>
        <extracomment>Descriptive text of the create wallet progress window which indicates to the user which wallet is currently being created.</extracomment>
        <translation type="unfinished">&lt;b&gt;%1&lt;/b&gt; cüzdanı yaradılır...</translation>
    </message>
    <message>
        <source>Create wallet failed</source>
        <translation type="unfinished">Cüzdan yaradıla bilmədi</translation>
    </message>
    <message>
        <source>Create wallet warning</source>
        <translation type="unfinished">Cüzdan yaradılma xəbərdarlığı</translation>
    </message>
    <message>
        <source>Can't list signers</source>
        <translation type="unfinished">İmzalaynları göstərmək mümkün deyil</translation>
    </message>
    </context>
<context>
    <name>LoadWalletsActivity</name>
    <message>
        <source>Load Wallets</source>
        <extracomment>Title of progress window which is displayed when wallets are being loaded.</extracomment>
        <translation type="unfinished">Cüzdanları yükləyin</translation>
    </message>
    <message>
        <source>Loading wallets…</source>
        <extracomment>Descriptive text of the load wallets progress window which indicates to the user that wallets are currently being loaded.</extracomment>
        <translation type="unfinished">Pulqabılar yüklənir...</translation>
    </message>
</context>
<context>
    <name>OpenWalletActivity</name>
    <message>
        <source>Open wallet failed</source>
        <translation type="unfinished">Pulqabı açıla bilmədi</translation>
    </message>
    <message>
        <source>Open wallet warning</source>
        <translation type="unfinished">Pulqabının açılması xəbərdarlığı</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <extracomment>Title of window indicating the progress of opening of a wallet.</extracomment>
        <translation type="unfinished">Cüzdanı açın</translation>
    </message>
    <message>
        <source>Opening Wallet &lt;b&gt;%1&lt;/b&gt;…</source>
        <extracomment>Descriptive text of the open wallet progress window which indicates to the user which wallet is currently being opened.</extracomment>
        <translation type="unfinished">&lt;b&gt;%1&lt;/b&gt; pulqabı açılır...</translation>
    </message>
</context>
<context>
    <name>RestoreWalletActivity</name>
    <message>
        <source>Restore Wallet</source>
        <extracomment>Title of progress window which is displayed when wallets are being restored.</extracomment>
        <translation type="unfinished">Cüzdanı bərpa et</translation>
    </message>
    <message>
        <source>Restoring Wallet &lt;b&gt;%1&lt;/b&gt;…</source>
        <extracomment>Descriptive text of the restore wallets progress window which indicates to the user that wallets are currently being restored.</extracomment>
        <translation type="unfinished">&lt;b&gt;%1&lt;/b&gt; cüzdanı bərpa olunur...</translation>
    </message>
    <message>
        <source>Restore wallet failed</source>
        <extracomment>Title of message box which is displayed when the wallet could not be restored.</extracomment>
        <translation type="unfinished">Cüzdan bərpa oluna bilmədi</translation>
    </message>
    <message>
        <source>Restore wallet warning</source>
        <extracomment>Title of message box which is displayed when the wallet is restored with some warning.</extracomment>
        <translation type="unfinished">Cüzdanın bərpa olunması xəbərdarlığı</translation>
    </message>
    <message>
        <source>Restore wallet message</source>
        <extracomment>Title of message box which is displayed when the wallet is successfully restored.</extracomment>
        <translation type="unfinished">Cüzdanın bərpası ismarıcı</translation>
    </message>
</context>
<context>
    <name>WalletController</name>
    <message>
        <source>Close wallet</source>
        <translation type="unfinished">Cüzdanı bağlayın</translation>
    </message>
    <message>
        <source>Are you sure you wish to close the wallet &lt;i&gt;%1&lt;/i&gt;?</source>
        <translation type="unfinished">&lt;i&gt;%1&lt;/i&gt; pulqabını bağlamaq istədiyinizə əminsiniz?</translation>
    </message>
    <message>
        <source>Closing the wallet for too long can result in having to resync the entire chain if pruning is enabled.</source>
        <translation type="unfinished">Pulqabının uzun müddət bağlı qaldıqda əgər budama (azalma) aktiv olarsa bu, bütün zəncirin təkrar eyniləşditrilməsi ilə nəticələnə bilər.</translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation type="unfinished">Bütün cüzdanları bağlayın</translation>
    </message>
    <message>
        <source>Are you sure you wish to close all wallets?</source>
        <translation type="unfinished">Bütün pulqabılarını bağlamaq istədiyinizə əminsiniz?</translation>
    </message>
</context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Create Wallet</source>
        <translation type="unfinished">Cüzdan yaradın</translation>
    </message>
    <message>
        <source>Wallet Name</source>
        <translation type="unfinished">Pulqabının adı</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation type="unfinished">Pulqabı</translation>
    </message>
    <message>
        <source>Encrypt the wallet. The wallet will be encrypted with a passphrase of your choice.</source>
        <translation type="unfinished">Pulqabının şifrələnməsi. Pulqabı sizin seçdiyiniz şifrəli söz ilə şifrələnəcək.</translation>
    </message>
    <message>
        <source>Encrypt Wallet</source>
        <translation type="unfinished">Pulqabını şifrələyin</translation>
    </message>
    <message>
        <source>Advanced Options</source>
        <translation type="unfinished">Əlavə parametrlər</translation>
    </message>
    <message>
        <source>Disable private keys for this wallet. Wallets with private keys disabled will have no private keys and cannot have an HD seed or imported private keys. This is ideal for watch-only wallets.</source>
        <translation type="unfinished">Bu pulqabının məxfi açarını söndürün. Məxfi açarı söndürülmüş pulqabılarında məxfi açarlar saxlanılmır, onlarda HD məxfi açarlar yaradıla bilıməz və məxfi açarlar idxal edilə bilməz. Bu sadəcə müşahidə edən pulqabıları üçün ideal variantdır.</translation>
    </message>
    <message>
        <source>Disable Private Keys</source>
        <translation type="unfinished">Məxfi açarları söndürün</translation>
    </message>
    <message>
        <source>Make a blank wallet. Blank wallets do not initially have private keys or scripts. Private keys and addresses can be imported, or an HD seed can be set, at a later time.</source>
        <translation type="unfinished">Boş pulqabı yaradın. Boş pulqabında ilkin olaraq açarlar və skriptlər yoxdur. Sonra məxfi açarlar və ünvanlar idxal edilə bilər və ya HD məxfi açarlar təyin edilə bilər.</translation>
    </message>
    <message>
        <source>Make Blank Wallet</source>
        <translation type="unfinished">Boş pulqabı yaradın</translation>
    </message>
    <message>
        <source>Use an external signing device such as a hardware wallet. Configure the external signer script in wallet preferences first.</source>
        <translation type="unfinished">Aparat cüzdanı kimi xarici imzalama cihazından istifadə edin. Əvvəlcə cüzdan seçimlərində xarici imzalayan skriptini konfiqurasiya edin.</translation>
    </message>
    <message>
        <source>External signer</source>
        <translation type="unfinished">Xarici imzalayıcı</translation>
    </message>
    <message>
        <source>Create</source>
        <translation type="unfinished">Yarat</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation type="unfinished">Ünvanda düzəliş et</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation type="unfinished">&amp;Etiket</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation type="unfinished">&amp;Ünvan</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation type="unfinished">Yeni göndərilmə ünvanı</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation type="unfinished">Qəbul ünvanını düzəliş et</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation type="unfinished">Göndərilmə ünvanını düzəliş et</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation type="unfinished">Yeni açar yaradılma uğursuz oldu.</translation>
    </message>
</context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>name</source>
        <translation type="unfinished">ad</translation>
    </message>
    </context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation type="unfinished">versiya</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation type="unfinished">Haqqında %1</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Welcome</source>
        <translation type="unfinished">Xoş gəlmisiniz</translation>
    </message>
    <message>
        <source>Reverting this setting requires re-downloading the entire blockchain. It is faster to download the full chain first and prune it later. Disables some advanced features.</source>
        <translation type="unfinished">Bu tənzimləməni geri almaq bütün blok zəncirinin yenidən endirilməsini tələb edəcək. Əvvəlcə tam zənciri endirmək və sonra budamaq daha sürətlidir. Bəzi qabaqcıl özəllikləri sıradan çıxarar.</translation>
    </message>
    <message>
        <source> GB</source>
        <translation type="unfinished">QB</translation>
    </message>
    <message numerus="yes">
        <source>%n GB of space available</source>
        <translation type="unfinished">
            <numerusform>%n GB of space available</numerusform>
            <numerusform>%n GB of space available</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform>(of %n GB needed)</numerusform>
            <numerusform>(of %n GB needed)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform>(%n GB needed for full chain)</numerusform>
            <numerusform>(%n GB needed for full chain)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform>(sufficient to restore backups %n day(s) old)</numerusform>
            <numerusform>(sufficient to restore backups %n day(s) old)</numerusform>
        </translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Xəta</translation>
    </message>
</context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Number of blocks left</source>
        <translation type="unfinished">Qalan blokların sayı</translation>
    </message>
    <message>
        <source>Unknown…</source>
        <translation type="unfinished">Bilinməyən...</translation>
    </message>
    <message>
        <source>calculating…</source>
        <translation type="unfinished">hesablanır...</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation type="unfinished">Gizlə</translation>
    </message>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation type="unfinished">Seçimlər</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation type="unfinished">&amp;Əsas</translation>
    </message>
    <message>
        <source>Open Configuration File</source>
        <translation type="unfinished">Konfiqurasiya Faylını Aç</translation>
    </message>
    <message>
        <source>&amp;Reset Options</source>
        <translation type="unfinished">&amp;Seçimləri Sıfırla</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation type="unfinished">&amp;Şəbəkə</translation>
    </message>
    <message>
        <source>GB</source>
        <translation type="unfinished">QB</translation>
    </message>
    <message>
        <source>Reverting this setting requires re-downloading the entire blockchain.</source>
        <translation type="unfinished">Bu tənzimləməni geri almaq bütün blok zəncirinin yenidən endirilməsini tələb edəcək. </translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished">&amp;Pəncərə</translation>
    </message>
    <message>
        <source>The user interface language can be set here. This setting will take effect after restarting %1.</source>
        <translation type="unfinished">İstifadəçi interfeys dili burada tənzimlənə bilər. Bu tənzimləmə %1 yenidən başladıldıqdan sonra təsirli olacaq.</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Ləğv et</translation>
    </message>
    <message>
        <source>Configuration options</source>
        <extracomment>Window title text of pop-up box that allows opening up of configuration file.</extracomment>
        <translation type="unfinished">Konfiqurasiya seçimləri</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation type="unfinished">Davam et</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Ləğv et</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Xəta</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Total:</source>
        <translation type="unfinished">Ümumi:</translation>
    </message>
    <message>
        <source>Recent transactions</source>
        <translation type="unfinished">Son əməliyyatlar</translation>
    </message>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    <message>
        <source>Copy to Clipboard</source>
        <translation type="unfinished">Buferə kopyala</translation>
    </message>
    <message>
        <source>Save…</source>
        <translation type="unfinished">Yadda saxla...</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished">Bağla</translation>
    </message>
    <message>
        <source>Failed to load transaction: %1</source>
        <translation type="unfinished">Əməliyyatı yükləmək alınmadı:%1</translation>
    </message>
    <message>
        <source>Total Amount</source>
        <translation type="unfinished">Ümumi Miqdar</translation>
    </message>
    <message>
        <source>or</source>
        <translation type="unfinished">və ya</translation>
    </message>
    </context>
<context>
    <name>PaymentServer</name>
    <message>
        <source>Payment request error</source>
        <translation type="unfinished">Ödəmə tələbinin xətası</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Address</source>
        <extracomment>Title of Peers Table column which contains the IP/Onion/I2P address of the connected peer.</extracomment>
        <translation type="unfinished">Ünvan</translation>
    </message>
    <message>
        <source>Network</source>
        <extracomment>Title of Peers Table column which states the network the peer connected through.</extracomment>
        <translation type="unfinished">Şəbəkə</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Network</source>
        <translation type="unfinished">Şəbəkə</translation>
    </message>
    <message>
        <source>&amp;Reset</source>
        <translation type="unfinished">&amp;Sıfırla</translation>
    </message>
    <message>
        <source>Node window</source>
        <translation type="unfinished">Qovşaq pəncərəsi</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <extracomment>Context menu action to copy the address of a peer.</extracomment>
        <translation type="unfinished">&amp;Ünvanı kopyalayın</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Ünvanı kopyalayın</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">&amp;Etiketi kopyalayın</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">&amp;Məbləği kopyalayın</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Məbləğ:</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Cüzdan:</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Tarix</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Etiket</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(etiket yoxdur)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Quantity:</source>
        <translation type="unfinished">Miqdar:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation type="unfinished">Baytlar:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Məbləğ:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation type="unfinished">Komissiya:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation type="unfinished">Komissiydan sonra:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation type="unfinished">Qalıq:</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation type="unfinished">Gizlə</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation type="unfinished">Miqdarı kopyalayın</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation type="unfinished">Məbləği kopyalayın</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation type="unfinished">Komissiyanı kopyalayın</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation type="unfinished">Komissyadan sonra kopyalayın</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation type="unfinished">Baytları koyalayın</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation type="unfinished">Dəyişikliyi kopyalayın</translation>
    </message>
    <message>
        <source>or</source>
        <translation type="unfinished">və ya</translation>
    </message>
    <message>
        <source>Total Amount</source>
        <translation type="unfinished">Ümumi Miqdar</translation>
    </message>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation type="unfinished">
            <numerusform>Estimated to begin confirmation within %n block(s).</numerusform>
            <numerusform>Estimated to begin confirmation within %n block(s).</numerusform>
        </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(etiket yoxdur)</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Tarix</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation type="unfinished">naməlum</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform>matures in %n more block(s)</numerusform>
            <numerusform>matures in %n more block(s)</numerusform>
        </translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Məbləğ</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Tarix</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Etiket</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(etiket yoxdur)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Other</source>
        <translation type="unfinished">Başqa</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Ünvanı kopyalayın</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">&amp;Etiketi kopyalayın</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">&amp;Məbləği kopyalayın</translation>
    </message>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">Vergüllə ayrılmış fayl</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation type="unfinished">Təsdiqləndi</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">Tarix</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Etiket</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">Ünvan</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">İxrac edilmədi</translation>
    </message>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">Yeni cüzdan yaradın</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Xəta</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;İxrac</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Hazırki vərəqdəki verilənləri fayla ixrac edin</translation>
    </message>
    <message>
        <source>Wallet Data</source>
        <extracomment>Name of the wallet data file format.</extracomment>
        <translation type="unfinished">Cüzdanı verilənləri</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Ləğv et</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Warning: Private keys detected in wallet {%s} with disabled private keys</source>
        <translation type="unfinished">Xəbərdarlıq: Gizli açarlar, sıradan çıxarılmış gizli açarlar ilə {%s} pulqabısında aşkarlandı.</translation>
    </message>
    <message>
        <source>default wallet</source>
        <translation type="unfinished">standart cüzdan</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation type="unfinished">Yükləmə tamamlandı</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation type="unfinished">Yetərsiz balans</translation>
    </message>
    <message>
        <source>The source code is available from %s.</source>
        <translation type="unfinished">Mənbə kodu %s-dən əldə edilə bilər.</translation>
    </message>
    <message>
        <source>Settings file could not be read</source>
        <translation type="unfinished">Ayarlar faylı oxuna bilmədi</translation>
    </message>
    <message>
        <source>Settings file could not be written</source>
        <translation type="unfinished">Ayarlar faylı yazıla bilmədi</translation>
    </message>
</context>
</TS>